# Pesto Test Resources

See Documentation for usage

For the default template, test_1 & test_2 are showcasing usages of a full request & optional arguments

This is not the place to write unit tests, but to store resources for said test

Refer to `project-root/tests` for unit tests that can be run with `pytest`
